Welcome to ClientVPS Mirrors

Help for package codexcopd
Type: Package
Title: The CODEX (Comorbidity, Obstruction, Dyspnea, and Previous Severe Exacerbations) Index: Short and Medium-Term Prognosis in Patients Hospitalized for Chronic Obstructive Pulmonary Disease (COPD) Exacerbations
Version: 0.1.0
Maintainer: Amin Adibi <adibi@alumni.ubc.ca>
Description: Predicts 3 to 12 months prognosis in Chronic Obstructive Pulmonary Disease (COPD) patients hospitalized for severe exacerbations, as described in Almagro et al. (2014) <doi:10.1378/chest.13-1328>.
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.0
NeedsCompilation: no
Packaged: 2020-05-12 21:49:23 UTC; maadibi
Author: Aida Kazemi [aut, cph], Amin Adibi [aut, cre]
Repository: CRAN
Date/Publication: 2020-05-18 15:20:10 UTC

The CODEX Index: Short and Medium-term Prognosis in Patients Hospitalized for COPD Exacerbations

Description

The CODEX Index: Short and Medium-term Prognosis in Patients Hospitalized for COPD Exacerbations

Usage

codex(age, charlson, FEV1, mMRC, exacerbation)

Arguments

age

a number for age

charlson

a number for charlson index

FEV1

a number for forced expiratory volume in one second (FEV1) expressed as percentage

mMRC

a number for the dyspnea scale of modified Medical Research Council (mMRC)

exacerbation

a number for severe exacerbations of COPD during the previous year (hospitalization or ED consultations)

https://www.ncbi.nlm.nih.gov/pubmed/24077342

Examples

codex (age = 40,charlson = 8 , FEV1 = 40, mMRC = 3, exacerbation = 2)
codex (age = 55,charlson = 4 , FEV1 = 40, mMRC = 3, exacerbation = 2)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.